@@ -1,7 +1,7 @@
 package Perinci::Sub::Gen::AccessTable;
 
-our $DATE = '2015-09-04'; # DATE
-our $VERSION = '0.54'; # VERSION
+our $DATE = '2016-02-13'; # DATE
+our $VERSION = '0.55'; # VERSION
 
 use 5.010001;
 use strict;
@@ -119,6 +119,8 @@ sub _gen_meta {
     my ($table_spec, $opts) = @_;
     my $langs = $opts->{langs};
 
+    my $fields = $table_spec->{fields};
+
     # add general arguments
 
     my $func_meta = {
@@ -190,7 +192,9 @@ _
         func_meta   => $func_meta,
         langs       => $langs,
         name        => 'sort',
-        type        => 'str',
+        type        => ['array*', {of=>['str*', {in=>[
+            map {($_, "-$_")} grep {$fields->{$_}{sortable}} sort keys %$fields,
+        ]}]}],
         default     => $opts->{default_sort},
         aliases     => $opts->{sort_aliases},
         cat_name    => 'ordering',
@@ -641,8 +645,7 @@ sub __parse_query {
     my @sort_fields;
     my @sorts;
     if (defined $args->{sort}) {
-        my @f = split /\s*[,;]\s*/, $args->{sort};
-        for my $f (@f) {
+        for my $f (@{ $args->{sort} }) {
             my $desc = $f =~ s/^-//;
             return err(400, "Unknown field in sort: $f")
                 unless $f ~~ @fields;
@@ -1035,11 +1038,11 @@ arguments.
   The random argument is an ordering option. If set to true, order of records
   returned will be shuffled first. This happened before paging.
 
-* *sort* => STR
+* *sort* => array of str
 
-  The sort argument is an ordering option, containing name of field. A - prefix
-  signifies descending instead of ascending order. Multiple fields are allowed,
-  separated by comma.
+  The sort argument is an ordering option, containing names of field. A `-`
+  prefix before the field name signifies descending instead of ascending order.
+  Multiple fields are allowed for secondary sort fields.
 
 * *q* => STR
 
@@ -1169,7 +1172,7 @@ _
                 "value in generated function's metadata",
         },
         default_sort => {
-            schema => 'str',
+            schema => ['array*', of=>'str*'],
             summary => "Supply default 'sort' ".
                 "value in generated function's metadata",
         },
@@ -1484,7 +1487,7 @@ Perinci::Sub::Gen::AccessTable - Generate function (and its metadata) to read ta
 
 =head1 VERSION
 
-This document describes version 0.54 of Perinci::Sub::Gen::AccessTable (from Perl distribution Perinci-Sub-Gen-AccessTable), released on 2015-09-04.
+This document describes version 0.55 of Perinci::Sub::Gen::AccessTable (from Perl distribution Perinci-Sub-Gen-AccessTable), released on 2016-02-13.
 
 =head1 SYNOPSIS
 
@@ -1588,6 +1591,10 @@ paging. The resulting function can then be run via command-line using
 L<Perinci::CmdLine> (as demonstrated in Synopsis), or served via HTTP using
 L<Perinci::Access::HTTP::Server>, or consumed normally by Perl programs.
 
+=head1 CAVEATS
+
+It is often not a good idea to expose your database schema directly as API.
+
 =head1 FUNCTIONS
 
 
@@ -1638,11 +1645,11 @@ I<result_start> to 21.
 The random argument is an ordering option. If set to true, order of records
 returned will be shuffled first. This happened before paging.
 
-=item * I<sort> => STR
+=item * I<sort> => array of str
 
-The sort argument is an ordering option, containing name of field. A - prefix
-signifies descending instead of ascending order. Multiple fields are allowed,
-separated by comma.
+The sort argument is an ordering option, containing names of field. A C<->
+prefix before the field name signifies descending instead of ascending order.
+Multiple fields are allowed for secondary sort fields.
 
 =item * I<q> => STR
 
@@ -1686,6 +1693,8 @@ to 0.
 
 =back
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -1741,7 +1750,7 @@ Supply default 'random' value in generated function's metadata.
 
 Supply default 'result_limit' value in generated function's metadata.
 
-=item * B<default_sort> => I<str>
+=item * B<default_sort> => I<array[str]>
 
 Supply default 'sort' value in generated function's metadata.
 
@@ -1931,10 +1940,6 @@ that contains extra information.
 
 Return value: A hash containing generated function, metadata (hash)
 
-=head1 CAVEATS
-
-It is often not a good idea to expose your database schema directly as API.
-
 =head1 FAQ
 
 =head2 I want my function to accept additional arguments.
@@ -1952,19 +1957,13 @@ You can use the C<extra_args> argument:
 As for the implementation, you can specify hooks to do things with the extra
 arguments.
 
-=head1 SEE ALSO
-
-L<Rinci>
-
-L<Perinci::CmdLine>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Sub-Gen-AccessTable>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-Sub-Gen-AccessTable>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-Sub-Gen-AccessTable>.
 
 =head1 BUGS
 
@@ -1974,13 +1973,19 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Rinci>
+
+L<Perinci::CmdLine>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
